Struct amazon_sp_notifications::models::sqs_resource::SqsResource
source · [−]pub struct SqsResource {
pub arn: String,
}Expand description
SqsResource : The information required to create an Amazon Simple Queue Service (Amazon SQS) queue destination.
Fields
arn: StringThe Amazon Resource Name (ARN) associated with the SQS queue.
Implementations
sourceimpl SqsResource
impl SqsResource
sourcepub fn new(arn: String) -> SqsResource
pub fn new(arn: String) -> SqsResource
The information required to create an Amazon Simple Queue Service (Amazon SQS) queue destination.